.. currentmodule:: rayoptics.parax

*********************
Paraxial Design Model
*********************

Overview
========

   Paraxial layout operations are handled via the :class:`~paraxialdesign.ParaxialModel`. This enables model manipulation via the |ybar| or |nubar| diagrams.

   Optical layout is facilitated by being able to use paraxial properties to solve for constructional parameters.
